@@ -1,27 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2018 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt Creator.
-**
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-****************************************************************************/
+// Copyright (C) 2018 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -36,8 +14,6 @@ namespace LanguageServerProtocol {
 
 class LANGUAGESERVERPROTOCOL_EXPORT JsonObject
 {
-    Q_DECLARE_TR_FUNCTIONS(LanguageServerProtocol::JsonObject)
-
 public:
     using iterator = QJsonObject::iterator;
     using const_iterator = QJsonObject::const_iterator;
@@ -87,19 +63,19 @@ protected:
     template<typename T>
     T typedValue(const QStringView key) const;
     template<typename T>
-    Utils::optional<T> optionalValue(const QStringView key) const;
+    std::optional<T> optionalValue(const QStringView key) const;
     template<typename T>
     LanguageClientValue<T> clientValue(const QStringView key) const;
     template<typename T>
-    Utils::optional<LanguageClientValue<T>> optionalClientValue(const QStringView key) const;
+    std::optional<LanguageClientValue<T>> optionalClientValue(const QStringView key) const;
     template<typename T>
     QList<T> array(const QStringView key) const;
     template<typename T>
-    Utils::optional<QList<T>> optionalArray(const QStringView key) const;
+    std::optional<QList<T>> optionalArray(const QStringView key) const;
     template<typename T>
     LanguageClientArray<T> clientArray(const QStringView key) const;
     template<typename T>
-    Utils::optional<LanguageClientArray<T>> optionalClientArray(const QStringView key) const;
+    std::optional<LanguageClientArray<T>> optionalClientArray(const QStringView key) const;
     template<typename T>
     void insertArray(const QStringView key, const QList<T> &array);
     template<typename>
@@ -112,7 +88,7 @@ private:
 template<typename T, typename V>
 JsonObject::iterator JsonObject::insertVariant(const QStringView key, const V &variant)
 {
-    return Utils::holds_alternative<T>(variant) ? insert(key, Utils::get<T>(variant)) : end();
+    return std::holds_alternative<T>(variant) ? insert(key, std::get<T>(variant)) : end();
 }
 
 template<typename T1, typename T2, typename... Args, typename V>
@@ -129,10 +105,10 @@ T JsonObject::typedValue(const QStringView key) const
 }
 
 template<typename T>
-Utils::optional<T> JsonObject::optionalValue(const QStringView key) const
+std::optional<T> JsonObject::optionalValue(const QStringView key) const
 {
     const QJsonValue &val = value(key);
-    return val.isUndefined() ? Utils::nullopt : Utils::make_optional(fromJsonValue<T>(val));
+    return val.isUndefined() ? std::nullopt : std::make_optional(fromJsonValue<T>(val));
 }
 
 template<typename T>
@@ -142,26 +118,26 @@ LanguageClientValue<T> JsonObject::clientValue(const QStringView key) const
 }
 
 template<typename T>
-Utils::optional<LanguageClientValue<T>> JsonObject::optionalClientValue(const QStringView key) const
+std::optional<LanguageClientValue<T>> JsonObject::optionalClientValue(const QStringView key) const
 {
-    return contains(key) ? Utils::make_optional(clientValue<T>(key)) : Utils::nullopt;
+    return contains(key) ? std::make_optional(clientValue<T>(key)) : std::nullopt;
 }
 
 template<typename T>
 QList<T> JsonObject::array(const QStringView key) const
 {
-    if (const Utils::optional<QList<T>> &array = optionalArray<T>(key))
+    if (const std::optional<QList<T>> &array = optionalArray<T>(key))
         return *array;
     qCDebug(conversionLog) << QString("Expected array under %1 in:").arg(key) << *this;
     return {};
 }
 
 template<typename T>
-Utils::optional<QList<T>> JsonObject::optionalArray(const QStringView key) const
+std::optional<QList<T>> JsonObject::optionalArray(const QStringView key) const
 {
     const QJsonValue &jsonValue = value(key);
     if (jsonValue.isUndefined())
-        return Utils::nullopt;
+        return std::nullopt;
     return Utils::transform<QList<T>>(jsonValue.toArray(), &fromJsonValue<T>);
 }
 
@@ -172,11 +148,11 @@ LanguageClientArray<T> JsonObject::clientArray(const QStringView key) const
 }
 
 template<typename T>
-Utils::optional<LanguageClientArray<T>> JsonObject::optionalClientArray(const QStringView key) const
+std::optional<LanguageClientArray<T>> JsonObject::optionalClientArray(const QStringView key) const
 {
     const QJsonValue &val = value(key);
-    return !val.isUndefined() ? Utils::make_optional(LanguageClientArray<T>(value(key)))
-                              : Utils::nullopt;
+    return !val.isUndefined() ? std::make_optional(LanguageClientArray<T>(value(key)))
+                              : std::nullopt;
 }
 
 template<typename T>
