@@ -1,5 +1,5 @@
 // Copyright (C) 2022 The Qt Company Ltd
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
@@ -22,7 +22,7 @@ public:
 
     static SquishSettings *squishSettings();
 
-    bool initialize(const QStringList &arguments, QString *errorString) override;
+    void initialize() override;
     bool delayedInitialize() override;
     ShutdownFlag aboutToShutdown() override;
 };
