@@ -1,31 +1,6 @@
 #!/usr/bin/env python3
-################################################################################
 # Copyright (C) The Qt Company Ltd.
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions are met:
-#
-#   * Redistributions of source code must retain the above copyright notice,
-#     this list of conditions and the following disclaimer.
-#   * Redistributions in binary form must reproduce the above copyright notice,
-#     this list of conditions and the following disclaimer in the documentation
-#     and/or other materials provided with the distribution.
-#   * Neither the name of The Qt Company Ltd, nor the names of its contributors
-#     may be used to endorse or promote products derived from this software
-#     without specific prior written permission.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
-# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
-# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-################################################################################
+# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
 
 import argparse
 import collections
@@ -135,9 +110,12 @@ def is_ignored_windows_file(use_debug, basepath, filename):
     return False
 
 def ignored_qt_lib_files(path, filenames):
+    # Qt ships some unneeded object files in the qml plugins
+    # On Windows we also do not want to ship the wrong debug/release .dlls or .lib files etc
     if not common.is_windows_platform():
-        return []
-    return [fn for fn in filenames if is_ignored_windows_file(debug_build, path, fn)]
+        return [fn for fn in filenames if fn.endswith('.cpp.o')]
+    return [fn for fn in filenames
+            if fn.endswith('.cpp.obj') or is_ignored_windows_file(debug_build, path, fn)]
 
 def copy_qt_libs(target_qt_prefix_path, qt_bin_dir, qt_libs_dir, qt_plugin_dir, qt_qml_dir, plugins):
     print("copying Qt libraries...")
@@ -295,13 +273,20 @@ def deploy_elfutils(qtc_install_dir, chrpath_bin, args):
     if common.is_mac_platform():
         return
 
+    libs = ['elf', 'dw']
+    version = '1'
+
     def lib_name(name, version):
         return ('lib' + name + '.so.' + version if common.is_linux_platform()
                 else name + '.dll')
 
-    version = '1'
-    libs = ['elf', 'dw']
-    elfutils_lib_path = os.path.join(args.elfutils_path, 'lib')
+    def find_elfutils_lib_path(path):
+        for root, _, files in os.walk(path):
+            if lib_name('elf', version) in files:
+                return root
+        return path
+
+    elfutils_lib_path = find_elfutils_lib_path(os.path.join(args.elfutils_path, 'lib'))
     if common.is_linux_platform():
         install_path = os.path.join(qtc_install_dir, 'lib', 'elfutils')
         backends_install_path = install_path
